[−][src]Struct gimli::read::SectionBaseAddresses
Optional base addresses for the relative DW_EH_PE_* encoded pointers
in a particular section.
See BaseAddresses for methods that are helpful in setting these addresses.
Fields
section: Option<u64>The address of the section containing the pointer.
text: Option<u64>The base address for text relative pointers.
This is generally the address of the .text section.
data: Option<u64>The base address for data relative pointers.
For pointers in the .eh_frame_hdr section, this is the address
of the .eh_frame_hdr section
For pointers in the .eh_frame section, this is generally the
global pointer, such as the address of the .got section.